@@ -597,28 +597,46 @@ class Code:
         graph = dct.get("mxGraphModel")
         root = graph.get("root")
         steps = root.get("object")
-        if steps is not None:
-            for shape in steps:
-                classname = shape.get("@Class")
-                module = shape.get("@Module")
-                function = shape.get("@Function")
-                variable = shape.get("@Output_variable")
-                label = shape.get("@label")
-                if classname is not None:
-                    if classname.startswith("%") and classname.endswith("%"):
-                        module, classname = self.search_modulename_in_flow(classname, steps)
-                doc = self.get_docstring_from_code(module, function, filepath, classname)
-                if doc is None:
-                    doc = ""
-                shape.update({'@Description': doc})
-                if classname is not None:
-                    if len(classname) == 0:
-                        shape.pop("@Class")
-                if variable is not None:
-                    if len(variable) == 0 and label.lower() != "template":
-                        shape.pop("@Output_variable")
-                # found.set('tooltip', doc)
-        self.saveflow(filepath, dct, original)
+        try:
+            if steps is not None:
+                for shape in steps:
+                    if hasattr(shape,"@Class"):
+                        classname = shape.get("@Class")
+                    else:
+                        classname = None
+                    if hasattr(shape, "@Module"):
+                        module = shape.get("@Module")
+                    else:
+                        module = None
+                    if hasattr(shape, "@Function"):
+                        function = shape.get("@Function")
+                    else:
+                        function = None
+                    if hasattr(shape, "@Output_variable"):
+                        variable = shape.get("@Output_variable")
+                    else:
+                        variable = None
+                    if hasattr(shape, "@label"):
+                        label = shape.get("@label")
+                    else:
+                        label = None
+                    if classname is not None:
+                        if classname.startswith("%") and classname.endswith("%"):
+                            module, classname = self.search_modulename_in_flow(classname, steps)
+                    doc = self.get_docstring_from_code(module, function, filepath, classname)
+                    if doc is None:
+                        doc = ""
+                    shape.update({'@Description': doc})
+                    if classname is not None:
+                        if len(classname) == 0:
+                            shape.pop("@Class")
+                    if variable is not None:
+                        if len(variable) == 0 and label.lower() != "template":
+                            shape.pop("@Output_variable")
+                    # found.set('tooltip', doc)
+            self.saveflow(filepath, dct, original)
+        except (ValueError, Exception):
+            raise Exception("Error. Probably the file is not a BPMN-RPA flow or the flow is incorrect.")
 
     @staticmethod
     def get_functions_from_module(module: str) -> Any:
@@ -639,6 +657,8 @@ class Code:
         :param modulepath: The path of the module to create the library for.
         :param libraryfolder: The folder in which the library will be created.
         """
+        modulepath = modulepath.replace("/", "\\")
+        libraryfolder = libraryfolder.replace("/", "\\")
         modulename = modulepath.split("\\")[-1].lower().replace(".py", "")
         libpath = fr"{libraryfolder}\{modulename}.xml"
         if not os.path.exists(libpath):
